==> cloudt-boot-starter-threadpool-3.1.2.8-20230411.054307-4-sources.jar: com/elitescloud/boot/threadpool/ThreadPoolAutoConfiguration.java <==
package com.elitescloud.boot.threadpool;

import com.dtp.common.config.DtpProperties;
import com.dtp.core.thread.DtpExecutor;
import com.elitescloud.boot.threadpool.common.ThreadPoolHolder;
import com.elitescloud.boot.threadpool.support.ContextTransferDelegate;
import com.elitescloud.boot.threadpool.support.CustomTaskExecutor;
import org.springframework.beans.BeansException;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.task.TaskExecutionAutoConfiguration;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.core.task.TaskExecutor;
import org.springframework.lang.NonNull;
import org.springframework.scheduling.annotation.AsyncAnnotationBeanPostProcessor;

/**
 * 线程池相关配置.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/21
 */
@Configuration(proxyBeanMethods = false)
@AutoConfigureBefore(TaskExecutionAutoConfiguration.class)
class ThreadPoolAutoConfiguration implements ApplicationContextAware {
    public static final String BEAN_NAME = "cloudt_taskExecutor";

    private final DtpProperties dtpProperties;

    public ThreadPoolAutoConfiguration(DtpProperties dtpProperties) {
        this.dtpProperties = dtpProperties;
    }

    @Bean({TaskExecutionAutoConfiguration.APPLICATION_TASK_EXECUTOR_BEAN_NAME, AsyncAnnotationBeanPostProcessor.DEFAULT_TASK_EXECUTOR_BEAN_NAME, BEAN_NAME})
    @Primary
    public TaskExecutor taskExecutor() {
        return new CustomTaskExecutor(dtpProperties);
    }

    @Bean
    public DtpExecutor cloudtDefaultDtpExecutor() {
        return (DtpExecutor) ThreadPoolHolder.createThreadPool(CustomTaskExecutor.CLOUDT_DTP_DEFAULT, CustomTaskExecutor.CLOUDT_TP, 8, 64);
    }

    @Override
    public void setApplicationContext(@NonNull ApplicationContext applicationContext) throws BeansException {
        ContextTransferDelegate.setApplicationContext(applicationContext);
    }
}

==> cloudt-boot-starter-threadpool-3.2.3.6-20230508.062946-1-sources.jar: com/elitescloud/boot/threadpool/ThreadPoolAutoConfiguration.java <==
package com.elitescloud.boot.threadpool;

import com.dtp.common.config.DtpProperties;
import com.dtp.core.thread.DtpExecutor;
import com.elitescloud.boot.threadpool.common.ThreadPoolHolder;
import com.elitescloud.boot.threadpool.support.ContextTransferDelegate;
import com.elitescloud.boot.threadpool.support.CustomTaskExecutor;
import org.springframework.beans.BeansException;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.task.TaskExecutionAutoConfiguration;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.core.task.TaskExecutor;
import org.springframework.lang.NonNull;
import org.springframework.scheduling.annotation.AsyncAnnotationBeanPostProcessor;

/**
 * 线程池相关配置.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/21
 */
@Configuration(proxyBeanMethods = false)
@AutoConfigureBefore(TaskExecutionAutoConfiguration.class)
public class ThreadPoolAutoConfiguration implements ApplicationContextAware, ApplicationRunner {
    public static final String BEAN_NAME = "cloudt_taskExecutor";

    private final DtpProperties dtpProperties;

    public ThreadPoolAutoConfiguration(DtpProperties dtpProperties) {
        this.dtpProperties = dtpProperties;
    }

    @Bean({TaskExecutionAutoConfiguration.APPLICATION_TASK_EXECUTOR_BEAN_NAME, AsyncAnnotationBeanPostProcessor.DEFAULT_TASK_EXECUTOR_BEAN_NAME, BEAN_NAME})
    @Primary
    public TaskExecutor taskExecutor() {
        return new CustomTaskExecutor(dtpProperties);
    }

    @Bean
    public DtpExecutor cloudtDefaultDtpExecutor() {
        return (DtpExecutor) ThreadPoolHolder.createThreadPool(CustomTaskExecutor.CLOUDT_DTP_DEFAULT, CustomTaskExecutor.CLOUDT_TP, 8, 64);
    }

    @Override
    public void setApplicationContext(@NonNull ApplicationContext applicationContext) throws BeansException {
        ContextTransferDelegate.setApplicationContext(applicationContext);
    }

    @Override
    public void run(ApplicationArguments args) throws Exception {
        ContextTransferDelegate.refreshContextTransfer();
    }
}
